@@ -1,3 +1,3 @@
 """Python client for connecting to the Geocaching API"""
 from .geocachingapi import GeocachingApi
-from .models import GeocachingSettings, GeocachingStatus
+from .models import GeocachingSettings, GeocachingStatus, GeocachingApiEnvironment
